==> sumo_1.15.0+dfsg.orig.tar.xz: sumo-1_15_0/tests/netedit/shapeelements/poigeo/inspect/color/test.py <==
#!/usr/bin/env python
# Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
# Copyright (C) 2009-2022 German Aerospace Center (DLR) and others.
# This program and the accompanying materials are made available under the
# terms of the Eclipse Public License 2.0 which is available at
# https://www.eclipse.org/legal/epl-2.0/
# This Source Code may also be made available under the following Secondary
# Licenses when the conditions for such availability set forth in the Eclipse
# Public License 2.0 are satisfied: GNU General Public License, version 2
# or later which is available at
# https://www.gnu.org/licenses/old-licenses/gpl-2.0-standalone.html
# SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later

# @file    test.py
# @author  Pablo Alvarez Lopez
# @date    2016-11-25

# import common functions for netedit tests
import os
import sys

testRoot = os.path.join(os.environ.get('SUMO_HOME', '.'), 'tests')
neteditTestRoot = os.path.join(
    os.environ.get('TEXTTEST_HOME', testRoot), 'netedit')
sys.path.append(neteditTestRoot)
import neteditTestFunctions as netedit  # noqa

# Open netedit
neteditProcess, referencePosition = netedit.setupAndStart(neteditTestRoot, ['--gui-testing-debug-gl'])

# go to shape mode
netedit.shapeMode()

# select POI in list of shapes
netedit.changeElement("poiGeo")

# create first POI
netedit.leftClick(referencePosition, 108, 50)

# go to inspect mode
netedit.inspectMode()

# inspect first POI
netedit.leftClick(referencePosition, 108, 50)

# change color using dialog
netedit.modifyColorAttribute(netedit.attrs.POIGEO.inspect.colorButton, 5, False)

# Change parameter 4 with a non valid value (dummy)
netedit.modifyAttribute(netedit.attrs.POIGEO.inspect.color, "dummyColor", False)

# Change parameter 4 with a non valid value (invalid format)
netedit.modifyAttribute(netedit.attrs.POIGEO.inspect.color, "255,255,500", False)

# Change parameter 4 with a valid value (valid format)
netedit.modifyAttribute(netedit.attrs.POIGEO.inspect.color, "blue", False)

# Change parameter 4 with a valid value (valid format)
netedit.modifyAttribute(netedit.attrs.POIGEO.inspect.color, "125,60,200", False)

# Check undos and redos
netedit.undo(referencePosition, 2)
netedit.redo(referencePosition, 2)

# save shapes
netedit.saveAdditionals(referencePosition)

# save network
netedit.saveNetwork(referencePosition)

# quit netedit
netedit.quit(neteditProcess)

==> sumo_1.18.0+dfsg.orig.tar.xz: sumo-1_18_0/tests/netedit/shapeelements/poigeo/inspect/color/test.py <==
#!/usr/bin/env python
# Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.dev/sumo
# Copyright (C) 2009-2023 German Aerospace Center (DLR) and others.
# This program and the accompanying materials are made available under the
# terms of the Eclipse Public License 2.0 which is available at
# https://www.eclipse.org/legal/epl-2.0/
# This Source Code may also be made available under the following Secondary
# Licenses when the conditions for such availability set forth in the Eclipse
# Public License 2.0 are satisfied: GNU General Public License, version 2
# or later which is available at
# https://www.gnu.org/licenses/old-licenses/gpl-2.0-standalone.html
# SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later

# @file    test.py
# @author  Pablo Alvarez Lopez
# @date    2016-11-25

# import common functions for netedit tests
import os
import sys

testRoot = os.path.join(os.environ.get('SUMO_HOME', '.'), 'tests')
neteditTestRoot = os.path.join(
    os.environ.get('TEXTTEST_HOME', testRoot), 'netedit')
sys.path.append(neteditTestRoot)
import neteditTestFunctions as netedit  # noqa

# Open netedit
neteditProcess, referencePosition = netedit.setupAndStart(neteditTestRoot)

# go to shape mode
netedit.shapeMode()

# select POI in list of shapes
netedit.changeElement("poiGeo")

# create first POI
netedit.leftClick(referencePosition, 360, 99)

# go to inspect mode
netedit.inspectMode()

# inspect first POI
netedit.leftClick(referencePosition, 360, 99)

# change color using dialog
netedit.modifyColorAttribute(netedit.attrs.POIGEO.inspect.colorButton, 5, False)

# Change parameter 4 with a non valid value (dummy)
netedit.modifyAttribute(netedit.attrs.POIGEO.inspect.color, "dummyColor", False)

# Change parameter 4 with a non valid value (invalid format)
netedit.modifyAttribute(netedit.attrs.POIGEO.inspect.color, "255,255,500", False)

# Change parameter 4 with a valid value (valid format)
netedit.modifyAttribute(netedit.attrs.POIGEO.inspect.color, "blue", False)

# Change parameter 4 with a valid value (valid format)
netedit.modifyAttribute(netedit.attrs.POIGEO.inspect.color, "125,60,200", False)

# Check undos and redos
netedit.undo(referencePosition, 2)
netedit.redo(referencePosition, 2)

# save Netedit config
netedit.saveNeteditConfig(referencePosition)

# quit netedit
netedit.quit(neteditProcess)
